Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(340)

Unified Diff: remoting/host/video_scheduler.h

Issue 850983002: Implement video frame acknowledgements in the chromoting protocol. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/host/video_scheduler.h
diff --git a/remoting/host/video_scheduler.h b/remoting/host/video_scheduler.h
index 3bcf27723f9d64f08ad97ba9d9c08e3c784dfbe0..215def01e007b6eaf40cbb5083de3d775a3a9e9e 100644
--- a/remoting/host/video_scheduler.h
+++ b/remoting/host/video_scheduler.h
@@ -33,13 +33,13 @@ class CursorShapeInfo;
namespace protocol {
class CursorShapeInfo;
class CursorShapeStub;
-class VideoStub;
+class VideoSender;
} // namespace protocol
// Class responsible for scheduling frame captures from a
// webrtc::DesktopCapturer, delivering them to a VideoEncoder to encode, and
// finally passing the encoded video packets to the specified VideoStub to send
// on the network.
//
// THREADING
//
@@ -92,7 +92,7 @@ class VideoScheduler : public base::RefCountedThreadSafe<VideoScheduler>,
scoped_ptr<webrtc::MouseCursorMonitor> mouse_cursor_monitor,
scoped_ptr<VideoEncoder> encoder,
protocol::CursorShapeStub* cursor_stub,
- protocol::VideoStub* video_stub);
+ protocol::VideoSender* video_stub);
// webrtc::DesktopCapturer::Callback implementation.
webrtc::SharedMemory* CreateSharedMemory(size_t size) override;
@@ -189,7 +189,7 @@ class VideoScheduler : public base::RefCountedThreadSafe<VideoScheduler>,
// Interfaces through which video frames and cursor shapes are passed to the
// client. These members are always accessed on the network thread.
protocol::CursorShapeStub* cursor_stub_;
- protocol::VideoStub* video_stub_;
+ protocol::VideoSender* video_sender_;
// Timer used to schedule CaptureNextFrame().
scoped_ptr<base::OneShotTimer<VideoScheduler> > capture_timer_;
@@ -33,13 +33,13 @@ class CursorShapeInfo;
// Class responsible for scheduling frame captures from a
// webrtc::DesktopCapturer, delivering them to a VideoEncoder to encode, and
-// finally passing the encoded video packets to the specified VideoStub to send
-// on the network.
+// finally passing the encoded video packets to the specified VideoSender to
+// send on the network.
//
// THREADING

Powered by Google App Engine
This is Rietveld 408576698